@@ -464,7 +464,7 @@ class EssbasicClient(AbstractClient):
 
 
     def ChannelCreatePreparedPersonalEsign(self, request):
-        """本接口（ChannelCreatePreparedPersonalEsign）用于创建导入个人印章
+        """本接口（ChannelCreatePreparedPersonalEsign）用于创建导入个人印章（处方单场景专用，使用此接口请与客户经理确认）。
 
         :param request: Request instance for ChannelCreatePreparedPersonalEsign.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreatePreparedPersonalEsignRequest`
